/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.rest.data;

import com.google.common.base.Objects;
import org.springframework.http.HttpStatus;

import javax.xml.bind.annotation.XmlRootElement;

import static com.google.common.base.Objects.toStringHelper;

@XmlRootElement
public class ResourceException {
  private HttpStatus status;
  private String exception;
  private String message;
  private int code;

  public ResourceException() {
  }

  public ResourceException(HttpStatus status, Throwable throwable) {
    this.exception = throwable.getClass().getSimpleName();
    this.message = throwable.getMessage();
    this.status = status;
    this.code = status.value();
  }

  public HttpStatus getStatus() {
    return status;
  }

  public void setStatus(HttpStatus status) {
    this.status = status;
  }

  public String getException() {
    return exception;
  }

  public void setException(String exception) {
    this.exception = exception;
  }

  public String getMessage() {
    return message;
  }

  public void setMessage(String message) {
    this.message = message;
  }

  public int getCode() {
    return code;
  }

  public void setCode(int code) {
    this.code = code;
  }

  @Override
  public boolean equals(Object o) {
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    ResourceException other = (ResourceException) o;
    return Objects.equal(status, other.status)
      && Objects.equal(exception, other.exception)
      && Objects.equal(message, other.message)
      && Objects.equal(code, other.code);
  }

  @Override
  public int hashCode() {
    return Objects.hashCode(status, exception, message, code);
  }

  @Override
  public String toString() {
    return toStringHelper(this)
      .add("status", status)
      .add("code", code)
      .add("exception", exception)
      .add("message", message)
      .toString();
  }
}