package fr.smallcrew.rest.data;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Sort;

import javax.xml.bind.annotation.XmlRootElement;
import java.util.List;

@XmlRootElement
public class WebPage<T> {
  private int number;
  private int size;
  private int totalPages;
  private int numberOfElements;
  private long totalElements;
  private boolean hasPreviousPage;
  private boolean isFirstPage;
  private boolean hasNexPage;
  private boolean isLastPage;
  private List<T> content;
  private boolean hasContent;
  private Sort sort;

  public WebPage() {
  }

  private WebPage(Page<T> page) {
    number = page.getNumber();
    size = page.getSize();
    totalPages = page.getTotalPages();
    numberOfElements = page.getNumberOfElements();
    totalElements = page.getTotalElements();
    hasPreviousPage = page.hasPreviousPage();
    isFirstPage = page.isFirstPage();
    hasNexPage = page.hasNextPage();
    isLastPage = page.isLastPage();
    content = page.getContent();
    hasContent = page.hasContent();
    sort = page.getSort();
  }

  public static <T> WebPage<T> from(Page<T> page) {
    return new WebPage<T>(page);
  }

  public int getNumber() {
    return number;
  }

  public void setNumber(int number) {
    this.number = number;
  }

  public int getSize() {
    return size;
  }

  public void setSize(int size) {
    this.size = size;
  }

  public int getTotalPages() {
    return totalPages;
  }

  public void setTotalPages(int totalPages) {
    this.totalPages = totalPages;
  }

  public int getNumberOfElements() {
    return numberOfElements;
  }

  public void setNumberOfElements(int numberOfElements) {
    this.numberOfElements = numberOfElements;
  }

  public long getTotalElements() {
    return totalElements;
  }

  public void setTotalElements(long totalElements) {
    this.totalElements = totalElements;
  }

  public boolean isHasPreviousPage() {
    return hasPreviousPage;
  }

  public void setHasPreviousPage(boolean hasPreviousPage) {
    this.hasPreviousPage = hasPreviousPage;
  }

  public boolean isFirstPage() {
    return isFirstPage;
  }

  public void setFirstPage(boolean firstPage) {
    isFirstPage = firstPage;
  }

  public boolean isHasNexPage() {
    return hasNexPage;
  }

  public void setHasNexPage(boolean hasNexPage) {
    this.hasNexPage = hasNexPage;
  }

  public boolean isLastPage() {
    return isLastPage;
  }

  public void setLastPage(boolean lastPage) {
    isLastPage = lastPage;
  }

  public List<T> getContent() {
    return content;
  }

  public void setContent(List<T> content) {
    this.content = content;
  }

  public boolean isHasContent() {
    return hasContent;
  }

  public void setHasContent(boolean hasContent) {
    this.hasContent = hasContent;
  }

  public Sort getSort() {
    return sort;
  }

  public void setSort(Sort sort) {
    this.sort = sort;
  }
}
