/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.rest.wadl;

import fr.smallcrew.rest.data.wadl.Method;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.servlet.mvc.condition.RequestMethodsRequestCondition;

import java.util.Collection;
import java.util.List;

import static com.google.common.collect.Lists.newArrayList;

public class MethodBuilder {
  private final java.lang.reflect.Method method;
  private final RequestMethodsRequestCondition methodConditions;
  private final Collection<MediaType> mediaTypes;

  public MethodBuilder(java.lang.reflect.Method method, RequestMethodsRequestCondition methodConditions,
                       Collection<MediaType> mediaTypes) {
    this.method = method;
    this.methodConditions = methodConditions;
    this.mediaTypes = mediaTypes;
  }

  public static MethodBuilder from(java.lang.reflect.Method method, RequestMethodsRequestCondition methodConditions,
                                   Collection<MediaType> mediaTypes) {
    return new MethodBuilder(method, methodConditions, mediaTypes);
  }

  public Collection<Method> build() {
    List<Method> mappingMethods = newArrayList();
    for (RequestMethod requestMethod : methodConditions.getMethods()) {
      Method mappingMethod = new Method();
      mappingMethod.setName(requestMethod.name());
      mappingMethod.setRequest(RequestBuilder.from(method, mediaTypes).build());
      mappingMethod.getResponse().add(ResponseBuilder.from(method, mediaTypes).build());
      mappingMethods.add(mappingMethod);
    }
    return mappingMethods;
  }
}
